@@ -1,16 +1,19 @@
 #!/usr/bin/env python
 
-import json
-import configparser
-import sys
 import argparse
-from json.decoder import JSONDecodeError
+import configparser
+import json
+import sys
+from datetime import date, datetime, time, timedelta
 from itertools import groupby
+from json.decoder import JSONDecodeError
+from re import findall
 from time import sleep
-from datetime import datetime, timedelta, date, time
+
 import requests
-from bs4 import BeautifulSoup
+
 from .version import __version__
+from .utils import backoff_retry
 
 
 class Badminton():
@@ -192,9 +195,7 @@ class Badminton():
             login_form['captcha'] = self.capt
 
             r = self.session.get(login_url)
-            soup = BeautifulSoup(r.text, features="html.parser")
-            login_form['execution'] = soup.select(
-                "input[name='execution']")[0]['value']
+            login_form['execution'] = findall('name="execution" value="(.*?)"', r.text)[0]
             login_form["username"] = self.netid
             login_form["password"] = self.password
 
@@ -336,7 +337,7 @@ class Badminton():
         if len(self.results) != 0:
             print('可能有未成功支付的订单，请手动支付')
 
-
+    @backoff_retry
     def run(self):
         self.login()
         self.wait()
